%%
% #######################################################################
%   Robust Control Design for Active Flutter Suppression
% #######################################################################
%   Julian Theis, Harald Pfifer, Peter Seiler
%   Department of Aerospace Engineering and Mechanics
%   University of Minnesota, Minneapolis 
%   AIAA 2016 SciTech Paper
% ########################################################################
% Control Design for Active Flutter Suppression Controller using Hinf mixed
% sensitivity loopshaping.
%
% ### DESIGN AND SYNTHESIS PART ###

% last modified 12/02/2015 Julian Theis

clearvars; 
close all;
w = {.1,300}; 
if exist('garyfyFigure','file')
    gopts = garyfyFigureOptions; gopts.LineWidth = 1.5;
end
bopt = bodeoptions; bopt.PhaseMatching = 'on'; bopt.PhaseMatchingFreq = 0.1;
addpath('.\auxil')
%% Aircraft Model                     | SYS_OPENLOOP, FULLSYS_OPENLOOP
%
% The control design starts from a ten state model, describing the
% longitudinal dynamics and including the first three symmetric elastic modes. 
% This model is based on Dave Schmidt's modeling framework and was greybox
% updated using the flight test data of the first chirp ID flight
% (2015-08-18) by Harald Pfifer.

addpath('.\model')
coeff = load('AeroCoeffUpdated-18-Aug-2015.mat');
Vinf = 33;  %m/s
[a,b,c,d] = greymodskoell(coeff.Cm,coeff.CL,coeff.CQ1,[],Vinf,coeff.ConstCoeff,coeff.AC);
sys_openloop = ss(a,b, [0 0 1 zeros(1,7);c], [zeros(1,2); d]); clear a b c d
sys_openloop.StateName = {'u', 'alpha', 'theta', 'q', 'eta1', 'eta1dot', 'eta2', 'eta2dot', 'eta3', 'eta3dot'};
sys_openloop.OutputName = {'theta', 'q', 'az', 'acc'}; sys_openloop.InputName = {'flap3', 'flap4'};

% The model has two inputs: the symmetric deflection of each of the
% surface pairs 3, and 4. That is, midboard flaps, and
% outboard flaps. Recall that the inboard flaps (2) are used as an aileron
% and therefore are not considered for this symmetric scenario.
% The outputs are pitch angle theta, the pitch rate q, the vertical acceleration 
% at the CG as measured by the rear center accelerometer acc_cr and a combined 
% sensor signal form the four accelerometers at the wing tips 
% ( acc = 0.25*(acc_lf+acc_lr+acc_rf+acc_rr) ). Since the DKS model only
% considers one half of the aircraft, this is currently modeled as 
% ( acc = 0.5*(acc_rf+acc_rr) ).
%
% The combined sensor signal is thought to capture the first symmetric
% wing bending mode plus the rigid body motion. With the rigid body 
% acceleration available, the controller can thus determine the relative
% deflection. Note that the phase difference of the sensors depends on
% qdot, and hence we believe it is more reasonable to provide both
% signals independently to the controller rather can combining it a priori.

% An open-loop model with full sensor/actuator dynamics and delay is also
% constructed. The sensor model includes 50 Hz low-pass filter for the
% pitch rate and 35 Hz low-pass filters for the accel signals. The actuator
% model is identified from frequency domain data and the time delay is
% assumed to be 25ms.

fullsys_openloop = model_sensor_skoll*sys_openloop*model_actuator_skoll*model_delay_skoll;
fullsys_openloop.InputName = {'flap3', 'flap4'};

%% Low-Order Equivalent Model                         | ACT, ACT_R
%
% To capture the phase loss due to these effects accurately in the synthesis 
% model, a second order approximation is computed. This approximitation is 
% verified to accurately capture the phase up to about 100 rad/s

act = pade([0 0 0 1]*model_sensor_skoll*[0 0 0 1]'*model_actuator_skoll*model_delay_skoll,5);
act_r = modred(balreal(act),3:size(act.a,1));
act_r.OutputName={'flap4'}; act_r.InputName={'flap4'}; act_r.StateName(:)={'act_r'};

figure(101)
bode(act,':',act_r,'r',bopt,w); grid; 
if exist('garyfyFigure','file');garyfyFigure;end;
legend('full actuator model','reduced actuator model','Location','Best')

%% Reduced-Order Open-Loop System                     | SYS_OPENLOOP_R
%
% For the synthesis model, the higher flex modes are residualized and 
% the surge velocity u is truncated. The reduced airframe model is then 
% combined with the low-order  equalivalent model that describes the 
% parasitic dynamics
sys_openloop_r = modred(sys_openloop(:,'flap4'),7:10,'residualize'); 
sys_openloop_r = modred(sys_openloop_r,1,'truncate')*act_r;

%% Synthesis Model                                    | SYN, FULLSYN                       
%
% For the flutter suppression controller, the three measurements q, az and 
% acc are used as inputs. The symmetric deflection of the outboard surfaces
% (flap4) is used as the effector. The model drops the theta state (and 
% output) since this is not required for the flutter suppression.

% To directly minimize the effect of structural vibration, the modal
% velocity of the flex mode is introduced as an auxiliary output.
addc = strcmp(sys_openloop_r.StateName,'eta1dot')';
syn = ss(sys_openloop_r.a,sys_openloop_r.b,[sys_openloop_r.c; addc], [sys_openloop_r.d; zeros(size(addc,1),1)]);
syn.OutputName = {'theta','q','az','accel','eta1dot'}; syn.InputName = {'flap4'};

% The theta output and state are removed from the model
syn = modred(syn(2:5,:),2,'truncate'); 

% For evaluation, a synthesis model that includes the full actuator and
% sensor dynamics, as well as the time delays is also constructed.
fulladdc = strcmp(fullsys_openloop.StateName,'eta1dot')';
fullsyn = ss(fullsys_openloop.a,fullsys_openloop.b,...
    [fullsys_openloop.c; fulladdc], [fullsys_openloop.d; zeros(size(fulladdc,1),2)]);
fullsyn.InputDelay = fullsys_openloop.InputDelay;
fullsyn.OutputName = {'theta','q','az','accel','eta1dot'}; 
fullsyn.InputName = {'flap3','flap4'}; fullsyn.StateName = fullsys_openloop.StateName;
fullsyn2 = fullsyn;
fullsyn = modred(fullsyn(2:5,2),[6 14 15],'truncate');

figure(102)
 bode(fullsyn,':',syn,'r',{10,100},bopt);grid;
 if exist('garyfyFigure','file');garyfyFigure;end;
legend('synthesis model + full actuator dynamics and delays','synthesis model','Location','Best')


%% H-Infinity Controller Design
%
% The weight Wd is set to 1 and the following weighting choices are made
% for the other weights:

Wz = 0.001; % modal damping
Wu = 1*makeweight(200,25,0.5)*makeweight(0.5,55,200); % control effort
W1 = 1;                                             % input disturbance  
W2 = 200*blkdiag(.055,0.75,1);                      % output disturbance
Wy = 0.06*blkdiag(0.005,0.005,0.01); 
% The weight Wu is designed as a band-stop, i.e. the control effort is to be
% kept low in steady state and high frequencies which effectively leads to
% a wash-out and roll-off in the controller.

% In order to synthesize an H-Infinity controller, a generalized plant is
% formulated that expresses the performance specification in terms of the
% system norm (to be thought of as a desired closed-loop shape).
% In this case, this objective is simply to decrease the peak in the
% transfer functions corresponding to the flex mode and the short period 
% mode and hence lower the resonant peak, i.e. increase damping.
 
% 'genplant' sets up generalized plant as described in the paper
Gweighted = genplant(syn,W1,W2,[], Wy, Wu, Wz); 
%%
% A controller is synthesized using the hinfsyn command. 
% A suboptimal two-step procedure and scaling are applied to improve numerics.
[K,FGK,gam,info] = hinfsyn(ssbal(Gweighted),3,1,'Method','ric');
[K,FGK,gam,info] = hinfsyn(ssbal(Gweighted),3,1,'Method','ric',...
                           'GMIN',gam*1.1,'GMAX',gam*1.1);                       
K.InputName=sys_openloop_r.OutputName(2:4);
K.OutputName = {'flap4'};
K.StateName(:) = {'K'};

% The generalized plant can be verified and used for tuning
figure(103)
bodemag(Gweighted(1:5,1:4),FGK,{1,100})

% The controller is of the same order as the generalized plant, i.e. has
% six states. Its band-pass behavior can be seen in its frequency response
damp(K)
figure(104)
bode(-K,w,bopt);grid;
if exist('garyfyFigure','file');garyfyFigure;end;

% Further, it can be verified that the desired decrease of the resonant
% peak in the transfer function corresponding to the flex mode is indeed
% achieved

 figure(105)
 bodemag(syn(4,:),'--',Wz(1,1)\FGK(size(FGK,1),1)/W1,'g',w);grid;
legend('open loop','closed loop','Location','NorthWest')
if exist('garyfyFigure','file');garyfyFigure;end;

%%
% The generalized plant is also verified using the full model
fullFGK = lft(genplant(fullsyn,W1,W2,[], Wy, Wu, Wz),K);
normFGK = norm(FGK,'inf');
normfullFGK = norm(pade(fullFGK,5),'inf');
degradation_percent = (normfullFGK-normFGK)/normFGK*100
%%              | CL
% Comparing the pole locations of the closed-loop with and without flutter
% suppression also clearly shows that the elastic damping was drastically
% increased. Further, there is only marginal influence on the short period
% damping, although the frequency is somehow altered.

Vinf2 = [24 27 30 33];
clearvars multisys_openloop multiCL
for kk = 1:size(Vinf2,2)    
[a,b,c,d] = greymodskoell(coeff.Cm,coeff.CL,coeff.CQ1,[],Vinf2(kk),coeff.ConstCoeff,coeff.AC);
sys_openloopKK = ss(a,b, [0 0 1 zeros(1,7);c], [zeros(1,2); d]); clear a b c d
multisys_openloop(:,:,kk) = model_sensor_skoll*sys_openloopKK*model_actuator_skoll;

multisys_openloop.InputName={'flap3','flap4'};
multisys_openloop.OutputName={'theta','q','az','acc'};
Kd = model_delay_skoll(1)*K;
Kd.OutputName = K.OutputName;
multiCL(:,:,kk) = feedback(multisys_openloop(:,:,kk),-Kd,'Names');
end

varypzmap(pade(multisys_openloop,1))
xlim([-50,5])
ylim([-2,50])
sgrid

varypzmap(pade(multiCL,1))
xlim([-50,5])
ylim([-2,50])
sgrid

%%
% The step response to a pitch command further demonstrates the
% effectiveness of the proposed flutter suppression controller over
% multiple airspeeds. It also shows that the interaction with pilot
% commands is very low, since all initial transients are essentially
% unaltered by the flutter suppression controller

figure(162)

    subplot(223)
    step(multisys_openloop(2,1),multiCL(2,1),'g:',0.5);grid;
    if exist('garyfyFigure','file');garyfyFigure;end;
    ylabel('q [deg/s]');ylim([-20 10])

    subplot(221)
    step(multisys_openloop(1,1),multiCL(1,1),'g:',0.5);grid;
    if exist('garyfyFigure','file');garyfyFigure;end;
    ylabel('theta [deg]')
    legend('open loop','w/ flutter suppression','Location','Best')

    subplot(222)
    step(multisys_openloop(3,1)*pi/180,multiCL(3,1)*pi/180,'g:',0.5);grid;
    ylabel('az [m/s^2]');ylim([-1 6])
    if exist('garyfyFigure','file');garyfyFigure;end;

    subplot(224)
    step(multisys_openloop(4,1)*pi/180,multiCL(4,1)*pi/180,'g:',0.5);grid;
    if exist('garyfyFigure','file');garyfyFigure;end;  
    ylabel('acc [m/s^2]');ylim([-1 6])