%%
% #######################################################################
%   Robust Control Design for Active Flutter Suppression
% #######################################################################
%   Julian Theis, Harald Pfifer, Peter Seiler
%   Department of Aerospace Engineering and Mechanics
%   University of Minnesota, Minneapolis 
%   AIAA 2016 SciTech Paper
% ########################################################################
% Control Design for Active Flutter Suppression Controller using Hinf mixed
% sensitivity loopshaping.
%
% ### ANALYSIS PART ###
%       run design and synthesis beforehand and keep variables in workspace
% 

% last modified 12/03/2015 Julian Theis

Vinf = 33; % Airspeed for analysis
bopts = bodeoptions;bopts.MagUnits = 'abs';
dense_n = 1000;             % number of points for frequency gridding
%%  Load Aircraft Model and combine with full sensor/actuator/delay dynamics
% Included are sensor dynamics for q (first order lowpass at 50Hz), az and
% acc (first order lowpass at 35Hz),
% second order actuator dynamics (~20Hz bandwidth) and 
% a delay of 0.025s.

coeff = load('AeroCoeffUpdated-18-Aug-2015.mat');
[a,b,c,d] = greymodskoell(coeff.Cm,coeff.CL,coeff.CQ1,[],Vinf,coeff.ConstCoeff,coeff.AC);
sys_openloop = ss(a,b(:,2),c,d(:,2));
sensor = [ zeros(3,1) eye(3,3)]*model_sensor_skoll*[zeros(1,3); eye(3,3)];
sensor.OutputName = {'q','az','acc'};
fullsys_openloop = sensor*sys_openloop*...
                   model_actuator_skoll*model_delay_skoll;
fullsys_openloop.InputName = {'flap4'};

%% Robustness Margins
% Robustness margins are calculated using the LOOPMARGIN command (called
% inside the function DisplayLoopmargin which also prints the data to the workspace)
%
% The considered metrics here are 
% - the classical single loop margins at both input and output 
% - the multi loop input disk margin 
%   (simultaneous gain and phase perturbation in all inputs)
% - the multi loop output disk margin 
%   (simultaneous gain and phase perturbation in all outputs)
% - the multi loop output disk margin 
%   (simultaneous gain and phase perturbation in all outputs)
% - the multi loop IO disk margin 
%   (simultaneous gain and phase perturbation in all inputs AND outputs)

[CMI,DMI,MMI,CMO,DMO,MMO,MMIO] = DisplayLoopmargin(...
                       fullsys_openloop,-K...
                       );
 
% Furthermore                   
% - the single loop disk margins at both input and output
%   (simultaneous gain and phase perturbation)
ny = 3;
for yy = 1:ny
OLtmp = feedback(fullsys_openloop,-K(1,setdiff(1:ny,yy)),'Names');
singleMMIO = loopmargin(OLtmp(yy,1),-K(1,yy),'mm');
fprintf('\t Single IO Disk Margin: \t\t %2.2f degrees / %2.2f dB \t at %3.1f rad/s\n',singleMMIO.PhaseMargin(2),db(singleMMIO.GainMargin(2)),singleMMIO.Frequency)
end          
                   
stable = CMI.Stable

%% Closed-Loop Transfer Function Analysis
% All relevant closed-loop (or broken loop) transfer functions are 
% calculated by LOOPSENS:
% So  : output sensitivity (I+P*C)^-1     with plant P and compensator C
% Si  : input sensitivity (I+C*P)^-1
% To  : complementary output sensitivity P*C(I+P*C)^-1
% Ti  : complementary input sensitivity C*P(I+C*P)^-1
% CSo : controller sensitivity 
% PSi : sensitivity to input disturbances
%
% There are several results that relate these transfer functions to robustness 
% against all kinds of unstructured uncertainties (eg. To for multiplicative
% output uncertainty). 
% Looking at the singular values of the transfer function PSi (input 
% disturbance to output) provides qualitative insight into
% the objective of disturbance attenuation. The influence of the pitch
% tracker on low frequency disturbances is clearly visible, which leads to
% the increase in sensitivity around 10-30 rad/s .
% Sensitivity with respect to the elastic mode between 30-40 rad/s is
% clearly decresed, with a moderate increase in the 40-50 rad/s range.
loops = loopsens(pade(fullsys_openloop,1),-K);
figure(30); sigma(pade(fullsys_openloop,1),loops.PSi,w); grid; 
if exist('garyfyFigure','file');garyfyFigure(gcf,gopts);end
legend('open loop (P)','closed loop (PSi)','Location','Best')
%%
% While a fully unstructured uncertainty at the inputs or outputs is
% overly consercative, analysing the allowed perturbations for individual
% channels gives a good impression of the frequency dependent robustness of
% the control loop. The following perturbations are considered with the
% transfer functions again calculated using LOOPSENS (called inside
% DisplayLoopsens)
% - the allowed multiplicative uncertainty |1/To| for each output 
% - the allowed multiplicative uncertainty |1/Ti| for each input 
% - the allowed additive uncertainty |1/CSo|

DisplayLoopsens(pade(fullsys_openloop,1),-K,w,'input');
DisplayLoopsens(pade(fullsys_openloop,1),-K,w,'output');
DisplayLoopsens(pade(fullsys_openloop,1),-K,w,'additive');

%% Robust Stability Test - Structural Mode Uncertainty
% Next, a robust stability analysis within the Mu framework is done to check
% against uncertainty in the natural frequency of the first structural
% mode.

% A parametric uncertainty of 10 percent is assumed in the natural frequency 
% of the first elastic mode of the DKS model. 
unc = 10;

% The uncertain model is constructed and plotted
coeff = load('AeroCoeffUpdated-18-Aug-2015.mat');
omega_unc = [ureal('omega1',coeff.AC.omega(1),'Percentage',unc) coeff.AC.omega(2)  coeff.AC.omega(3)];
coeff.AC.omega = omega_unc;
[a,b,c,d] = greymodskoell(coeff.Cm,coeff.CL,coeff.CQ1,[],Vinf,coeff.ConstCoeff,coeff.AC);
sys_openloop_unc = ss(a,b(:,2),c, d(:,2)); clear a b c d

figure(201);
pzmap(sys_openloop_unc(2,1),sys_openloop(2,1))
xlim([-90,10]);ylim([0 100]);sgrid
legend('uncertain','nominal','Location','Best')
title(['Pole-Zero Map with ' int2str(omega_unc.Uncertainty.omega1.Percentage(2)) '% Uncertainty in Structural Mode Frequency'])
if exist('garyfyFigure','file');garyfyFigure(gcf,gopts);end

figure(202);
bode(sys_openloop_unc(2,1),sys_openloop(2,1),bopt,w)
legend('uncertain','nominal','Location','Best');
if exist('garyfyFigure','file');garyfyFigure(gcf,gopts);end
CL_unc = feedback(sensor*sys_openloop_unc*model_actuator_skoll*model_delay_skoll,-K);
CL_unc = complexify(pade(CL_unc,5),0.05); %regularize mu problem

% Mu Analysis is performed in a first step using the default grid and in a
% second step using a dense grid on the critical frequency range. The
% results indicate robust stability for the considered uncertainty.
[STABMARG,DESTABUNC,REPORT,INFO] = robuststab(pade(CL_unc,1));
CL_unc_grid = ufrd(pade(CL_unc,1),logspace(log10(20),log10(30),dense_n));
[STABMARGdense,DESTABUNCdense,REPORTdense,INFOdense] = robuststab(CL_unc_grid);
REPORTdense

figure(203)
bodemag(INFO.MussvBnds(1,1),INFOdense.MussvBnds(1,1),bopts,w);grid
title(['Robust Stability with ' int2str(CL_unc.Uncertainty.omega1.Percentage(2)) '% Uncertainty in Structural Mode Frequency'])
legend('default frequency grid', 'dense frequency grid','Location','Best')
ylabel('Upper Mu Bound');
 if exist('garyfyFigure','file');garyfyFigure;end;

%% Robust Performance Test - Structural Mode Uncertainty
% The uncertainty range can be reduced for the robust performance analysis
 sys_openloop_unc.Uncertainty.omega1.Percentage = 10*[-1 1];
 
% The generalized plant is reconstructed with the uncertain plant
fullsys_unc = sensor*sys_openloop_unc*model_actuator_skoll*model_delay_skoll;
fullsyn_unc = uss(fullsys_unc.a,fullsys_unc.b,[fullsys_unc.c; fulladdc(:,1:15)], [fullsys_unc.d; zeros(size(fulladdc,1),1)]);
fullsyn_unc.InputDelay = fullsys_unc.InputDelay;
fullFGK_unc = lft(genplant(fullsyn_unc,W1,W2,[], Wy, Wu, Wz),K);

% Mu Analysis is performed in a first step using the default grid and in a
% second step using a dense grid on the critical frequency range. 
figure(204)
wcgainplot(norm(pade(fullFGK(5,1),1),'inf')\pade(fullFGK_unc(5,1),1),{10,50});grid
gain = wcgain(norm(pade(fullFGK(5,1),1),'inf')\pade(fullFGK_unc(5,1),1),logspace(log10(25),log10(30),dense_n))
title(['Robust Performance with ' int2str(fullFGK_unc.Uncertainty.omega1.Percentage(2)) '% Uncertainty in Structural Mode Frequency'])
 if exist('garyfyFigure','file');garyfyFigure;end;

 
 
%% Robust Stability Test - Aero Coefficient Uncertainty
% Next, a robust stability analysis within the Mu framework is done to check
% against uncertainty in the aerodynamic coefficients.

% A parametric uncertainty of 40 percent is assumed in CLalpha, CLq,
% CMalpha, CLq and the "elastic derivatives" of the DKS model. 
unc = 40;

% The uncertain model is constructed and plotted
coeff= load('AeroCoeffUpdated-18-Aug-2015.mat');
Cm_unc = [ ureal('CMalpha',coeff.Cm(1),'Percentage',unc) ; ureal('CMq',coeff.Cm(2),'Percentage',unc) ; coeff.Cm(3:6)];
CL_unc = [ ureal('CLalpha',coeff.CL(1),'Percentage',unc) ; ureal('CLq',coeff.CL(2),'Percentage',unc) ; coeff.CL(3:6)];
CQ1_unc = [ ureal('CQ1alpha',coeff.CQ1(1),'Percentage',unc) ; ureal('CQ1q',coeff.CQ1(2),'Percentage',unc) ; coeff.CQ1(3) ; ureal('CQ1del4',coeff.CQ1(4),'Percentage',unc) ; coeff.CQ1(5:6)];
[a,b,c,d] = greymodskoell(Cm_unc,CL_unc,CQ1_unc,[],Vinf,coeff.ConstCoeff,coeff.AC);
sys_openloop_unc = ss(a,b(:,2),c,  d(:,2));

figure(205);
pzmap(sys_openloop_unc,sys_openloop)
xlim([-90,10]);ylim([0 100]);sgrid
legend('uncertain','nominal','Location','Best')
title(['Pole-Zero Map with ' int2str(sys_openloop_unc.Uncertainty.CLalpha.Percentage(2)) ' % Uncertainty in Aero Coefficients'])
if exist('garyfyFigure','file');garyfyFigure(gcf,gopts);end

figure(206);
bode(sys_openloop_unc(2,1),sys_openloop(2,1),bopt,w)
legend('uncertain','nominal','Location','Best')
title(['Bode Plot with ' int2str(sys_openloop_unc.Uncertainty.CLalpha.Percentage(2)) ' % Uncertainty in Aero Coefficients']);
if exist('garyfyFigure','file');garyfyFigure(gcf,gopts);end
CL_unc = feedback(sensor*sys_openloop_unc*model_actuator_skoll*model_delay_skoll,-K);
CL_unc = complexify(CL_unc,0.05); %regularize mu problem
if exist('garyfyFigure','file');garyfyFigure;end

% Mu Analysis is performed in a first step using the default grid and in a
% second step using a dense grid on the critical frequency range.
[STABMARG,DESTABUNC,REPORT,INFO] = robuststab(pade(CL_unc,1));
CL_unc_grid = ufrd(pade(CL_unc,1),logspace(log10(30),log10(40),dense_n));
[STABMARGdense,DESTABUNCdense,REPORTdense,INFOdense] = robuststab(CL_unc_grid);
REPORTdense

figure(207)
bodemag(INFO.MussvBnds(1,1),INFOdense.MussvBnds(1,1),bopts,w);grid;
title(['Robust Stability with ' int2str(CL_unc.Uncertainty.CLalpha.Percentage(2)) ' % Uncertainty in Aero Coefficients'])
legend('default frequency grid', 'dense frequency grid','Location','Best')
ylabel('Upper Mu Bound');
if exist('garyfyFigure','file');garyfyFigure(gcf,gopts);end

%% Robust Performance Test - Aero Coefficient Uncertainty
%
% The generalized plant is reconstructed with the uncertain plant
fullsys_unc = sensor*sys_openloop_unc*model_actuator_skoll*model_delay_skoll;
fullsyn_unc = uss(fullsys_unc.a,fullsys_unc.b,[fullsys_unc.c; fulladdc(:,1:15)], [fullsys_unc.d; zeros(size(fulladdc,1),1)]);
fullsyn_unc.InputDelay = fullsys_unc.InputDelay;
fullFGK_unc = lft(genplant(fullsyn_unc,W1,W2,[], Wy, Wu, Wz),K);

% Mu Analysis is performed in a first step using the default grid and in a
% second step using a dense grid on the critical frequency range. 
figure(208)
wcgainplot(norm(pade(fullFGK(5,1),1),'inf')\pade(fullFGK_unc(5,1),1),{10,50});grid
gain = wcgain(norm(pade(fullFGK(5,1),1),'inf')\pade(fullFGK_unc(5,1),1),logspace(log10(30),log10(40),dense_n))
title(['Robust Performance with ' int2str(fullFGK_unc.Uncertainty.CLalpha.Percentage(2)) ' % Uncertainty in Aero Coefficients'])
ylim([-20,20])
if exist('garyfyFigure','file');garyfyFigure;end



%% Robust Stability Test - Dynamic Actuator Uncertainty.
% Next, a robust stability analysis within the Mu framework is done to check
% against dynamic uncertainty in the actuator model.

% A parametric dynamic of 60 percent is assumed. 
unc_act = 60;

% The uncertain model is constructed and plotted
act_unc = ultidyn('act_unc',[1 1],'bound',0.01*unc_act);
coeff = load('AeroCoeffUpdated-18-Aug-2015.mat');
[a,b,c,d] = greymodskoell(coeff.Cm,coeff.CL,coeff.CQ1,[],Vinf,coeff.ConstCoeff,coeff.AC);
sys_openloop_unc = ss(a,b(:,2),c,d(:,2));

figure(209);
pzmap(sys_openloop_unc*(1+act_unc)*model_actuator_skoll,sys_openloop*model_actuator_skoll)
xlim([-90,10]);ylim([0 100]);sgrid
legend('uncertain','nominal','Location','Best')
title(['Pole-Zero Map with actuator uncertainty' ])
if exist('garyfyFigure','file');garyfyFigure(gcf,gopts);end

figure(210);
bode(sys_openloop_unc(1,1)*(1+act_unc)*model_actuator_skoll,sys_openloop(1,1)*model_actuator_skoll,bopt,w)
legend('uncertain','nominal','Location','Best')
title(['Bode Plot with  with actuator uncertainty']);
if exist('garyfyFigure','file');garyfyFigure;end
CL_unc = feedback(sensor*sys_openloop_unc*(1+act_unc)*model_actuator_skoll*model_delay_skoll,-K);

% Mu Analysis is performed in a first step using the default grid and in a
% second step using a dense grid on the critical frequency range.
[STABMARG,DESTABUNC,REPORT,INFO] = robuststab(pade(CL_unc,1));
CL_unc_grid = ufrd(pade(CL_unc,1),logspace(log10(25),log10(35),dense_n));
[STABMARGdense,DESTABUNCdense,REPORTdense,INFOdense] = robuststab(CL_unc_grid);
REPORTdense

figure(211)
bodemag(INFO.MussvBnds(1,1),INFOdense.MussvBnds(1,1),bopts,w);grid;
title(['Robust Stability with ' num2str(CL_unc.Uncertainty.act_unc.bound) 'norm bound in Actuator'])
legend('default frequency grid', 'dense frequency grid','Location','Best')
ylabel('Upper Mu Bound'); 
if exist('garyfyFigure','file');garyfyFigure;end

%% Robust Performance Test - Dynamic Actuator Uncertainty
%
% The generalized plant is reconstructed with the uncertain plant
fullsys_unc = sensor*sys_openloop_unc;
fullsyn_unc = ss(fullsys_unc.a,fullsys_unc.b,[fullsys_unc.c; fulladdc(:,1:13)], [fullsys_unc.d; zeros(size(fulladdc,1),1)]);
fullsyn_unc = fullsyn_unc*(1+act_unc)*model_actuator_skoll*model_delay_skoll;
fullFGK_unc = lft(genplant(fullsyn_unc,W1,W2,[], Wy, Wu, Wz),K);

figure(212)
wcgainplot(norm(pade(fullFGK(5,1),1),'inf')\pade(fullFGK_unc(5,1),1),{10,50});grid
gain = wcgain(norm(pade(fullFGK(5,1),1),'inf')\pade(fullFGK_unc(5,1),1),logspace(log10(25),log10(35),dense_n))
title(['Robust Performance with ' num2str(fullFGK_unc.Uncertainty.act_unc.bound) 'norm bound in Actuator'])
if exist('garyfyFigure','file');garyfyFigure(gcf,gopts);end



%% Robust Stability Test - Structural Mode & Aero Coefficient Uncertainty & Actuator Uncertainty
% Last, a robust stability analysis within the Mu framework is done to check
% against combined uncertainty.
% A parametric uncertainty of 2 percent is assumed in the structural mode
% frequency.
% A parametric uncertainty of 20 percent is assumed in the aerodynamic coefficients. 
% A dynamic uncertainty of 10 percent is assumed in the actuator.
unc_aero = 20;
unc_struc = 2;
unc_act = 10;

% The uncertain model is constructed and plotted
coeff = load('AeroCoeffUpdated-18-Aug-2015.mat');
Cm_unc = [ ureal('CMalpha',coeff.Cm(1),'Percentage',unc_aero) ; ureal('CMq',coeff.Cm(2),'Percentage',unc_aero) ; coeff.Cm(3:6)];
CL_unc = [ ureal('CLalpha',coeff.CL(1),'Percentage',unc_aero) ; ureal('CLq',coeff.CL(2),'Percentage',unc_aero) ; coeff.CL(3:6)];
CQ1_unc = [ ureal('CQ1alpha',coeff.CQ1(1),'Percentage',unc_aero) ; ureal('CQ1q',coeff.CQ1(2),'Percentage',unc_aero) ; coeff.CQ1(3) ; ureal('CQ1del4',coeff.CQ1(4),'Percentage',unc_aero) ; coeff.CQ1(5:6)];
omega_unc = [ureal('omega',coeff.AC.omega(1),'Percentage',unc_struc) coeff.AC.omega(2) coeff.AC.omega(3)];
coeff.AC.omega = omega_unc;
[a,b,c,d] = greymodskoell(Cm_unc,CL_unc,CQ1_unc,[],Vinf,coeff.ConstCoeff,coeff.AC);
sys_openloop_unc = ss(a,b(:,2),c,d(:,2));
act_unc = ultidyn('act_unc',[1 1],'bound',0.01*unc_act);

figure(213);
pzmap(sys_openloop_unc,sys_openloop)
xlim([-90,10]);ylim([0 100]);sgrid
legend('uncertain','nominal','Location','Best')
title(['Pole-Zero Map with ' int2str(sys_openloop_unc.Uncertainty.CLalpha.Percentage(2)) ' % Uncertainty in Aero Coefficients,  ' int2str(sys_openloop_unc.Uncertainty.omega.Percentage(2)) ' % in Strucutral Mode'])
if exist('garyfyFigure','file');garyfyFigure(gcf,gopts);end

figure(214);
bode(sys_openloop_unc(1,1),sys_openloop(1,1),bopt,w)
legend('uncertain','nominal','Location','Best')
title(['Bode Plot with  ' int2str(sys_openloop_unc.Uncertainty.CLalpha.Percentage(2)) ' % Uncertainty in Aero Coefficients,  ' int2str(sys_openloop_unc.Uncertainty.omega.Percentage(2)) ' % in Strucutral Mode']);
if exist('garyfyFigure','file');garyfyFigure;end

CL_unc = feedback(sensor*sys_openloop_unc*(1+act_unc)*model_actuator_skoll*model_delay_skoll,-K);
CL_unc = complexify(CL_unc,0.05); %regularize mu problem

% Mu Analysis is performed in a first step using the default grid and in a
% second step using a dense grid on the critical frequency range.
[STABMARG,DESTABUNC,REPORT,INFO] = robuststab(pade(CL_unc,1));
CL_unc_grid = ufrd(pade(CL_unc,1),logspace(log10(25),log10(35),dense_n));
[STABMARGdense,DESTABUNCdense,REPORTdense,INFOdense] = robuststab(CL_unc_grid);
REPORTdense

figure(215)
bodemag(INFO.MussvBnds(1,1),INFOdense.MussvBnds(1,1),bopts,w);grid;
title(['Robust Stability with ' int2str(CL_unc.Uncertainty.CLalpha.Percentage(2)) ' % Uncertainty in Aero Coefficients,  ' int2str(CL_unc.Uncertainty.omega.Percentage(2)) ' % in Strucutral Mode and  ' num2str(CL_unc.Uncertainty.act_unc.bound) 'norm bound in Actuator'])
legend('default frequency grid', 'dense frequency grid','Location','Best')
ylabel('Upper Mu Bound'); 
if exist('garyfyFigure','file');garyfyFigure;end

%% Robust Performance Test - Structural Mode & Aero Coefficient Uncertainty & Actuator Uncertainty
%
% The generalized plant is reconstructed with the uncertain plant
fullsys_unc = sensor*sys_openloop_unc;
fullsyn_unc = uss(fullsys_unc.a,fullsys_unc.b,[fullsys_unc.c; fulladdc(:,1:13)], [fullsys_unc.d; zeros(size(fulladdc,1),1)]);
fullsyn_unc = fullsyn_unc*(1+act_unc)*model_actuator_skoll*model_delay_skoll;
fullFGK_unc = lft(genplant(fullsyn_unc,W1,W2,[], Wy, Wu, Wz),K);

figure(216)
wcgainplot(norm(pade(fullFGK(5,1),1),'inf')\pade(fullFGK_unc(5,1),1),{10,50});grid
gain = wcgain(norm(pade(fullFGK(5,1),1),'inf')\pade(fullFGK_unc(5,1),1),logspace(log10(25),log10(35),dense_n))
title(['Robust Performance with ' int2str(fullFGK_unc.Uncertainty.CLalpha.Percentage(2)) ' % Uncertainty in Aero Coefficients,  ' int2str(fullFGK_unc.Uncertainty.omega.Percentage(2)) ' % in Strucutral Mode and  ' num2str(fullFGK_unc.Uncertainty.act_unc.bound) 'norm bound in Actuator'])
ylim([-20,20])
if exist('garyfyFigure','file');garyfyFigure;end




%% Rate and Deflection Limit Verification
% Deflection and rate limits are roughly bounded by a singular value
% analysis.

% A disturbance model is constructed as an additional input to alpha dot
sys_disturbance = sensor*ss(a,b,c,d)*model_actuator_skoll;
sys_disturbance = ss(sys_disturbance.a,[sys_disturbance.b [zeros(4,1);1;zeros(12,1)]] ,sys_disturbance.c,[sys_disturbance.d zeros(3,1)]);  
% The delay is incorporated in the controller with a second order Pade
% approximation. 
Kd = model_delay_skoll(2)*(K-K.d);  %(K-K.d) just removes numerical noise

% MIL-F-8785C Dryden gust model
L = 30;  %altitude in feet < 1000
W20 = 15;% wind speed at 20ft  15 / 30 / 45 knots for typical / moderate / severe turbulence
sig = 0.1*W20   /Vinf  ; %conversion to alpha
% dryden filter differentiated, because disturbance is input to alpha dot
% Gust = sig*sqrt(L/(pi*Vinf))     *     tf([sqrt(3)*L/(Vinf)  1],[L/(Vinf) 1]) * tf([1 0], [L/(Vinf) 1]);

% Two low-pass filters are used as models for the pilot and gusts. The gust
% filter is further differentiated to account for the disturbance input on
% alpha dot
Pilot = 35/180*pi*tf(1,[1/5 1]); 
 Gust = 5/180*pi*tf([1 0],[1/5 1]);

% The interconnection is calculated such that pilot inputs use the midboard
% flaps and gust inputs instantaneously change the angle of attack. 
systemnames = 'sys_disturbance Kd Gust Pilot';
inputvar = '[cmd{1}; alpha{1}]';
outputvar = '[sys_disturbance; Kd]';
input_to_sys_disturbance = '[ Pilot; Kd; Gust ]';
input_to_Pilot = '[cmd]';
input_to_Gust = '[alpha]';
input_to_Kd = '[ sys_disturbance ]';
cleanupsysic = 'yes';
GustCL = sysic;

[~,GustCL] = isproper([eye(4);[ 0 0 0 tf('s')]]*GustCL);
GustCL.OutputName = {'q','az','wing az','control','rate'};

% Step responses and Singular Value Analysis are performed
figure(217)
step(GustCL,0.5)
 if exist('garyfyFigure','file');garyfyFigure;end;
 
figure(218)
sigma((35/180*pi)\GustCL(4,:),(400/180*pi)\GustCL(5,:),{1,200})
 if exist('garyfyFigure','file');garyfyFigure;end;
