function [a,b,c,d] = greymodskoell(Cm,CL,CQ1,Ts,Vinf,ConstCoeff,AC)

% Forms the state-space model from the longitudinal rigid-body and aeroelastic 
% dimensional stability derivatives.
% Vinf and Xcg must be defined, as well as all the stability derivatives.
% In this version, the first three sym modes are included

%   Units: SI

% **************************************


% For the identification, the phugoid and higher flex modes are set
% constant and only the short period derivatives and the first symmetric
% bending is varied. 

%Gross aircraft mass [kg] (including relevant hardware)
m = AC.m;
% Gross moments of inertia [Jx Jy Jz Jxz] [kg*m^2]
Iyy = AC.Iyy;
% Mean aerodynamic chord [m]
c = AC.c;
% Wing area [m^2]
S = AC.S;

% Generalized Masses
mgen1 = AC.mgen(1);
mgen2 = AC.mgen(2);
mgen3 = AC.mgen(3);

% Structural Dynamics
omega1 = AC.omega(1);
omega2 = AC.omega(2);
omega3 = AC.omega(3);

zet1 = AC.zeta(1);
zet2 = AC.zeta(2);
zet3 = AC.zeta(3);

% Flight parameters
rho = 1.155; % air density [kg/m3]
qbar = Vinf^2*rho/2; %dynamic pressure

% common coefficients
c2U0=c/2/Vinf;
qSc = qbar*S*c;
qS = qbar*S;


%% Initialize free parameters

Malf = Cm(1)/Iyy*qSc;
Mq = Cm(2)/Iyy*qSc*c2U0;
Mdele3 = Cm(3)/Iyy*qSc;
Mdele4 = Cm(4)/Iyy*qSc;
Meta1 = Cm(5)/Iyy*qSc;
Meta1dot = Cm(6)/Iyy*qSc/Vinf;

Zalf = -CL(1)/m*qS;
Zq = -CL(2)/m*qS*c2U0; 
Zdele3 = -CL(3)/m*qS;
Zdele4 = -CL(4)/m*qS;
Zeta1 = -CL(5)/m*qS;
Zeta1dot = -CL(6)/m*qS/Vinf;

XI1alf = CQ1(1)/mgen1*qSc;
XI1q = CQ1(2)/mgen1*qSc/Vinf;
XI1dele3 = CQ1(3)/mgen1*qSc;
XI1dele4 = CQ1(4)/mgen1*qSc;
XI1eta1 = CQ1(5)/mgen1*qSc;
XI1eta1dot = CQ1(6)/mgen1*qSc/Vinf;



%% Define parameters
%
% Still a mess to get the phugoid derivatives in a proper dimenionless form

% Phugoid derivatives (taken from DKS email on 7/25/15)
Xu = -0.04; % HP: only added to stabilize the phugoid! 
% Xalf = 21.13;
% Xq = -0.1033;
% Zu = -0.9816;
Mu = 0;

% Xdele3 = -0.9343;
% Xdele4 = -1.078;

CXalf = 0.5495; 
CXq = -0.33475;
CXdele3 = -0.024297;
CXdele4 = -0.028034;
CLtrim = 0.0077807; %0.077807; %0.0077807;

Xalf =  CXalf*qS/m; %7.3063; %
Xq = CXq*qS*c2U0/m;
Xdele3 = CXdele3*qS/m;
Xdele4 = CXdele4*qS/m;
Zu = -CLtrim/Vinf*2/m*qS; %-0.0066457*Vinf;%


%%
%
% Dimensionalize the constant coefficients 

CLeta2 =  ConstCoeff.CL(1);
CLeta2dot = ConstCoeff.CL(2);
CLeta3 = ConstCoeff.CL(3);
CLeta3dot = ConstCoeff.CL(4);

Zeta2 = - CLeta2/m*qS;
Zeta2dot = - CLeta2dot/m*qS/Vinf;
Zeta3 = - CLeta3/m*qS;
Zeta3dot = - CLeta3dot/m*qS/Vinf;

Cmeta2 = ConstCoeff.Cm(1);
Cmeta2dot = ConstCoeff.Cm(2);
Cmeta3 = ConstCoeff.Cm(3);
Cmeta3dot = ConstCoeff.Cm(4);

Meta2 = Cmeta2/Iyy*qSc;
Meta2dot = Cmeta2dot/Iyy*qSc/Vinf;
Meta3 = Cmeta3/Iyy*qSc;
Meta3dot = Cmeta3dot/Iyy*qSc/Vinf;

CQ1eta2 = ConstCoeff.CQ1(1);
CQ1eta2dot = ConstCoeff.CQ1(2);
CQ1eta3 = ConstCoeff.CQ1(3);
CQ1eta3dot = ConstCoeff.CQ1(4);

XI1eta2 = CQ1eta2/mgen1*qSc;
XI1eta2dot = CQ1eta2dot/mgen1*qSc/Vinf;
XI1eta3 = CQ1eta3/mgen1*qSc;
XI1eta3dot = CQ1eta3dot/mgen1*qSc/Vinf;


CQ2alf = ConstCoeff.CQ2(1);
CQ2q = ConstCoeff.CQ2(2);
CQ2dele3 = ConstCoeff.CQ2(3);
CQ2dele4 = ConstCoeff.CQ2(4);
CQ2eta1 = ConstCoeff.CQ2(5);
CQ2eta1dot = ConstCoeff.CQ2(6);
CQ2eta2 =  ConstCoeff.CQ2(7);
CQ2eta2dot =  ConstCoeff.CQ2(8);
CQ2eta3 =  ConstCoeff.CQ2(9);
CQ2eta3dot =  ConstCoeff.CQ2(10);

XI2alf = CQ2alf/mgen2*qSc;
XI2q = CQ2q/mgen2*qSc/Vinf;
XI2dele3 = CQ2dele3/mgen2*qSc;
XI2dele4 = CQ2dele4/mgen2*qSc;
XI2eta1 = CQ2eta1/mgen2*qSc;
XI2eta1dot = CQ2eta1dot/mgen2*qSc/Vinf;
XI2eta2 = CQ2eta2/mgen2*qSc;
XI2eta2dot = CQ2eta2dot/mgen2*qSc/Vinf;
XI2eta3 = CQ2eta3/mgen2*qSc;
XI2eta3dot = CQ2eta3dot/mgen2*qSc/Vinf;


CQ3alf = ConstCoeff.CQ3(1);
CQ3q = ConstCoeff.CQ3(2);
CQ3dele3 =  ConstCoeff.CQ3(3);
CQ3dele4 =  ConstCoeff.CQ3(4);
CQ3eta1 = ConstCoeff.CQ3(5);
CQ3eta1dot =  ConstCoeff.CQ3(6);
CQ3eta2 =   ConstCoeff.CQ3(7);
CQ3eta2dot =  ConstCoeff.CQ3(8);
CQ3eta3 = ConstCoeff.CQ3(9);
CQ3eta3dot = ConstCoeff.CQ3(10);

XI3alf = CQ3alf/mgen3*qSc;
XI3q = CQ3q/mgen3*qSc/Vinf;
XI3dele3 = CQ3dele3/mgen3*qSc;
XI3dele4 = CQ3dele4/mgen3*qSc;
XI3eta1 = CQ3eta1/mgen3*qSc;
XI3eta1dot = CQ3eta1dot/mgen3*qSc/Vinf;
XI3eta2 = CQ3eta2/mgen3*qSc;
XI3eta2dot = CQ3eta2dot/mgen3*qSc/Vinf;
XI3eta3 = CQ3eta3/mgen3*qSc;
XI3eta3dot = CQ3eta3dot/mgen3*qSc/Vinf;

%% Build state space model

% The 24 Parameters below are the rigid-body dimensional stability derivatives.
% Their values need to be defined via input somehow.

% Malf, Mq, Mu, Mdele1, Mdele2, Mdele3, Mdele4;
% Xalf, Xq, Xu, Xdele1, Xdele2, Xdele3, Xdele4;
% Zalf, Zq, Zu, Zdele1, Zdele2, Zdele3, Zdele4;

% Will now put in form Mxdot=Ax + Bu, -> xdot = [MinvA]x + [MinvB]u
% This is the state model for just the rigid-body subsystem
% which will be expanded below into the ndof system

a=[Xu Xalf -32.2 Xq;Zu/Vinf Zalf/Vinf 0 (1+Zq/Vinf);
   0 0 0  1;Mu Malf 0 Mq];
b=[Xdele3 Xdele4;
   Zdele3/Vinf Zdele4/Vinf;
   0 0;Mdele3 Mdele4];
c=[0,0,0,1];d=zeros(1,2);

% Longitudinal states are u, alpha, theta, q; inputs are flaps 1-4, Units, ft, rad, sec
% Add'l elastic states are eta1, eta1dot, eta2, eta2dot, eta3, eta3dot

% The 48 Parameters below are the aeroelastic dimensional stability derivatives.
% Their values also need to be defined via input somehow.

% Zeta1, Zeta2, Zeta3, Zeta1dot Zeta2dot, Zeta3dot
% Meta1, Meta2, Meta3, Meta1dot, Meta2dot, Meta3dot
% XI1alf, XI2alf, XI3alf, XI1q, XI2q, XI3q, XI1dele1, XI2dele1, XI3dele1
% XI1dele2, XI2dele2, XI3dele2, XI1dele3, XI2dele3, XI3dele3
% XI1dele4, XI2dele4, XI3dele4, XI1eta1, XI2eta1, XI3eta1
% XI1eta2, XI2eta2, XI3eta2, XI1eta3, XI2eta3, XI3eta3
% XI1eta1dot, XI2eta1dot, XI3eta1dot, XI1eta2dot, XI2eta2dot, XI3eta2dot
% XI1eta3dot, XI2eta3dot, XI3eta3dot

% Will now insert these aeroelastic coefficients into the state matrices for the ndof system

andof=[a,zeros(4,6);zeros(6,10)];
andof(2,5:10)=[Zeta1/Vinf,Zeta1dot/Vinf,Zeta2/Vinf,Zeta2dot/Vinf,Zeta3/Vinf,Zeta3dot/Vinf];
andof(4,5:10)=[Meta1,Meta1dot,Meta2,Meta2dot,Meta3,Meta3dot];
andof(5,6)=1;
% andof(6,1:10)=[0,XI1alf,0,XI1q,XI1eta1-omega1^2,XI1eta1dot-2*zet1*omega1...
%             XI1eta2,XI1eta2dot,XI1eta3,XI1eta3dot];   %JT does not work
%             with uncertain omega
andof(7,8)=1;
andof(8,1:10)=[0,XI2alf,0,XI2q,XI2eta1,XI2eta1dot...
            XI2eta2-omega2^2,XI2eta2dot-2*zet2*omega2,XI2eta3,XI2eta3dot];
andof(9,10)=1;
andof(10,1:10)=[0,XI3alf,0,XI3q,XI3eta1,XI3eta1dot...
            XI3eta2,XI3eta2dot,XI3eta3-omega3^2,XI3eta3dot-2*zet3*omega3];

        
andof = andof + [ zeros(5,10) ; %JT for uncertain parameter
        0,XI1alf,0,XI1q,XI1eta1-omega1^2,XI1eta1dot-2*zet1*omega1,XI1eta2,XI1eta2dot,XI1eta3,XI1eta3dot ;
         zeros(4,10) ];
        
        
bndof=[b;zeros(6,2)];bndof(6,:)=[XI1dele3 XI1dele4];
bndof(8,:)=[XI2dele3 XI2dele4];
bndof(10,:)=[XI3dele3 XI3dele4];

cndof=[c,zeros(1,6)];dndof=zeros(3,2);


% Unit conversions
m2f = 3.28084; %meter to feet
Vinf = Vinf*m2f;


% Will now add add'l responses to c and d matrices
% Notes: "Vinf" is flight velocity in fps - MUST BE DEFINED
%        "Xcg" is cg location measured aft from the nose in feet - MUST BE DEFINED

cndof(1,:)=[0 0 0 1 0 -0.46234 0 0.28952 0 0.32729];dndof(1,:)=[0 0 ]; % Pitch rate on Centerbody


% xacg=Xcg-XEAwing(1); % Distance aft from node 1 to cg, for accel @ cg.- ft
% zaccel=[0 Vinf -Vinf 0 0 (mode1z(1)+xacg*mode1t(1))...
%        0 (mode2z(1)+xacg*mode2t(1)) 0 (mode3z(1)+xacg*mode3t(1))];

% Values updated by Dave 7/30/15
zaccelr=[0 Vinf -Vinf -2.6667e-02 0 -2.4029e-01 0 3.7033e-02 0 2.2423e-01];
cndof(2,:)=m2f^(-1) *zaccelr*andof;dndof(2,:)=m2f^(-1) *zaccelr*bndof; % z accel - aft accelerometer on Centerbody


% DelXaft=(15.55+FEM.EA_points_coordinates(31,2))/12-Xcg;  % distance aft from cg to aft right accel, ft
% zaccelr=[0 Vinf -Vinf DelXaft 0 -ModeShape.EA_modeshape7(31,4)...   % accel at node 9006
%          0 -ModeShape.EA_modeshape10(31,4) 0 -ModeShape.EA_modeshape11(31,4)];

% Values updated by Dave 7/30/15
zaccelrr=[0 Vinf -Vinf 1.3283 0 0.53681 0  -0.085759 0 -0.16162];

% DelXaft=(15.55+FEM.EA_points_coordinates(30,2))/12-Xcg;  % distance aft from cg to fwd right accel, ft
% zaccelr=[0 Vinf -Vinf DelXaft 0 -ModeShape.EA_modeshape7(30,4)...  % accel at accel node 9005
%          0 -ModeShape.EA_modeshape10(30,4) 0 -ModeShape.EA_modeshape11(30,4)];

% Values updated by Dave 7/30/15
zaccelrf=[0 Vinf -Vinf 1.1133 0  0.66429 0 0.28398 0 -0.059278];


cndof(3,:)=m2f^(-1) *(zaccelrr*andof + zaccelrf*andof)/2;
dndof(3,:)=m2f^(-1) *(zaccelrr*bndof + zaccelrf*bndof)/2; % z accel, right wing symmetric.


% Form state-space model
a = andof;%([2,4,5,6],[2,4,5,6]);
b = bndof;%([2,4,5,6],:);
c = cndof;%(:,[2,4,5,6]);
d = dndof;